@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION @ISA);
-$VERSION = '0.22';
+$VERSION = '0.23';
 
 #--------------------------------------------------------------------------
 
@@ -44,17 +44,19 @@ use constant	OZ2G    => 28.3495231;  # number of grams in an ounce (oz)
 use constant	IN2MM   => 25.4;        # number of inches in a millimetre (mm)
 
 my %LANG = (
+    'cz' => { Publisher => 'Vydavatel',     Author => 'Autor',          Title => 'Titul',   Length => 'Délka',      Pages => 'Počet stran: ' },
     'de' => { Publisher => 'Verlag',        Author => 'Autor',          Title => 'Titel',   Length => qr{L.+nge},   Pages => 'Seiten' },
     'en' => { Publisher => 'Publisher',     Author => 'Author',         Title => 'Title',   Length => 'Length',     Pages => 'pages'  },
     'fr' => { Publisher => '.+diteur',      Author => 'Auteur',         Title => 'Titre',   Length => 'Longueur',   Pages => 'pages'  },
     'fi' => { Publisher => 'Kustantaja',    Author => 'Kirjoittaja',    Title => 'Otsikko', Length => 'Pituus',     Pages => 'sivua'  },
     'nl' => { Publisher => 'Uitgever',      Author => 'Auteur',         Title => 'Titel',   Length => 'Lengte',     Pages => q[pagina's]  },
     'md' => { Publisher => 'Editor',        Author => 'Autor',          Title => 'Titlu',   Length => 'Lungime',    Pages => 'pagini'  },
-    'ru' => { Publisher => 'Издатель',      Author => 'Автор',          Title => 'Название',    
-                                                                                            Length => 'Количество страниц',     
-                                                                                                                    Pages => 'Всего страниц:'  },
-    'iw' => { Publisher => '\\x\{5d4\}\\x\{5d5\}\\x\{5e6\}\\x\{5d0\}\\x\{5d4\}', 
-                                            Author => 'Author',         Title => 'Title',   Length => '\\x\{5d0\}\\x\{5d5\}\\x\{5e8\}\\x\{5da\}', 
+    'ru' => { Publisher => 'Издатель|\\x\{418\}\\x\{437\}\\x\{434\}\\x\{430\}\\x\{442\}\\x\{435\}\\x\{43b\}\\x\{44c\}',
+                                            Author => 'Автор',          Title => 'Название',
+                                                                                            Length => 'Количество страниц|\\x\{41a\}\\x\{43e\}\\x\{43b\}\\x\{438\}\\x\{447\}\\x\{435\}\\x\{441\}\\x\{442\}\\x\{432\}\\x\{43e\} \\x\{441\}\\x\{442\}\\x\{440\}\\x\{430\}\\x\{43d\}\\x\{438\}\\x\{446\}',
+                                                                                                                    Pages => 'Всего страниц:|\\x\{412\}\\x\{441\}\\x\{435\}\\x\{433\}\\x\{43e\} \\x\{441\}\\x\{442\}\\x\{440\}\\x\{430\}\\x\{43d\}\\x\{438\}\\x\{446\}:'  },
+    'iw' => { Publisher => '\\x\{5d4\}\\x\{5d5\}\\x\{5e6\}\\x\{5d0\}\\x\{5d4\}',
+                                            Author => 'Author',         Title => 'Title',   Length => '\\x\{5d0\}\\x\{5d5\}\\x\{5e8\}\\x\{5da\}',
                                                                                                                     Pages => '\\x\{5e2\}\\x\{5de\}\\x\{5d5\}\\x\{5d3\}\\x\{5d9\}\\x\{5dd\}'  }
 );
 
@@ -69,7 +71,7 @@ my %LANG = (
 
 =item C<search>
 
-Creates a query string, then passes the appropriate form fields to the 
+Creates a query string, then passes the appropriate form fields to the
 GoogleBooks server.
 
 The returned page should be the correct catalog page for that ISBN. If not the
@@ -77,7 +79,7 @@ function returns zero and allows the next driver in the chain to have a go. If
 a valid page is returned, the following fields are returned via the book hash:
 
   isbn          (now returns isbn13)
-  isbn10        
+  isbn10
   isbn13
   ean13         (industry name)
   author
@@ -104,7 +106,7 @@ sub search {
 
     # validate and convert into EAN13 format
     my $ean = $self->convert_to_ean13($isbn);
-    return $self->handler("Invalid ISBN specified")   
+    return $self->handler("Invalid ISBN specified")
         unless($ean);
 
 	my $mech = WWW::Mechanize->new();
@@ -150,18 +152,18 @@ sub search {
 #print STDERR "\n# html=[$html]\n";
 
     $data->{url} = $mech->uri();
+    my ($ccTLD) = $data->{url} =~ m{^http://[.\w]+\.google\.(\w\w)\b};
+
     my $lang = 'en';                                                                # English (default)
     $lang = 'de'    if($data->{url} =~ m{^http://[.\w]+\.google\.(de|ch|at)\b});    # German
     $lang = 'iw'    if($data->{url} =~ m{^http://[.\w]+\.google\.co\.il\b});        # Hebrew
-    $lang = 'fr'    if($data->{url} =~ m{^http://[.\w]+\.google\.(fr)\b});          # French
-    $lang = 'fi'    if($data->{url} =~ m{^http://[.\w]+\.google\.(fi)\b});          # Finnish
-    $lang = 'nl'    if($data->{url} =~ m{^http://[.\w]+\.google\.(nl)\b});          # Dutch
+    $lang = $ccTLD  if($LANG{$ccTLD});                                              # we have a ccTLD translation
 
 	return $self->handler("Language '".uc $lang."'not currently supported, patches welcome.")
 		if($lang =~ m!xx!);
-    
+
     _match( $html, $data, $lang );
-    
+
     # remove HTML tags
     for(qw(author)) {
         next unless(defined $data->{$_});
@@ -247,7 +249,7 @@ sub _match {
     ($data->{pages})                    = $html =~ m!<td class="metadata_label">(?:<span[^>]*>)?$LANG{$lang}->{Length}(?:</span>)?</td><td class="metadata_value">(?:<span[^>]*>)?$LANG{$lang}->{Pages}\s+(\d+)(?:</span>)?</td>!s  unless($data->{pages});
     ($data->{pages})                    = $html =~ m!<td class="metadata_value"><span[^>]*>(\d+) \\x\{5e2\}\\x\{5de\}\\x\{5d5\}\\x\{5d3\}\\x\{5d9\}\\x\{5dd\}</span></td>!si   unless($data->{pages});
 
-    $data->{author} =~ s/"//g;    
+    $data->{author} =~ s/"//g;
     $data->{thumb} = $data->{image};
 }
 
